<?php /**
 * Ennova functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
 * @subpackage Ennova
 * @since 1.0.0
 */

	define( 'ENNOVA_THEME_DIR', get_template_directory() . '/' );
	define( 'ENNOVA_THEME_URI', get_template_directory_uri() . '/' );
	
	
	$ennova_theme_path = get_template_directory() . '/inc/ansar/';

	//require( $ennova_theme_path . '/ennova-custom-navwalker.php' );
	require( $ennova_theme_path . '/class-bootstrap-navwalker.php' );

	//Customizer Files
	require( $ennova_theme_path  . '/customizer/general.php');
	require( $ennova_theme_path  . '/customizer/footer.php');
	
	//Customizer Range Controls
	require( $ennova_theme_path  . '/customizer-control/class-customizer-range-value-control/class-customizer-range-value-control.php');

	//Customizer checkbox image Controls
	require( $ennova_theme_path  . '/customizer-control/class-customizer-image-control/class-customizer-image-control.php');

	/* custom-color file. */
	require( get_template_directory() . '/css/colors/custom-color.php');

	/* custom-style file. */
	require( get_template_directory() . '/css/custom-style.php');

	/*-----------------------------------------------------------------------------------*/
	/*	Enqueue scripts and styles.
	/*-----------------------------------------------------------------------------------*/
	require( $ennova_theme_path .'/enqueue.php');

if ( ! function_exists( 'ennova_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function ennova_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on ennova, use a find and replace
	 * to change 'ennova' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'ennova', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/* Add theme support for gutenberg block */
	add_theme_support( 'align-wide' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary menu', 'ennova' ),
        'footer' => __( 'Footer menu', 'ennova' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/**
		 * Custom background support.
		 */
	add_theme_support( 'custom-background' );

    // Set up the woocommerce feature.
    add_theme_support( 'woocommerce');

     // Woocommerce Gallery Support
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );

    // Added theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );
	
	add_theme_support( 'custom-logo', array(
			'height'      => 40,
			'width'       => 210,
			'flex-height' => true,
			'flex-width' => true,
			'header-text' => array( 'site-title', 'site-description' ),
		) );
}
endif;
add_action( 'after_setup_theme', 'ennova_setup' );


	function ennova_the_custom_logo() {
	
		if ( function_exists( 'the_custom_logo' ) ) 
			the_custom_logo();
	}

	add_filter('get_custom_logo','ennova_logo_class');


	function ennova_logo_class($html)
	{
	$html = str_replace('custom-logo-link', 'navbar-brand', $html);
	return $html;
	}

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function ennova_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'ennova_content_width', 640 );
}
add_action( 'after_setup_theme', 'ennova_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function ennova_widgets_init() {

	$ennova_footer_column_layout = esc_attr(get_theme_mod('ennova_footer_column_layout',3));
	
	$ennova_footer_column_layout = 12 / $ennova_footer_column_layout;

	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar Widget Area', 'ennova' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<div id="%1$s" class="mg-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="mg-wid-title"><h6>',
		'after_title'   => '</h6></div>',
	) );

	 register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area', 'ennova' ),
		'id'            => 'footer_widget_area',
		'description'   => '',
		'before_widget' => '<div id="%1$s" class="col-md-'.$ennova_footer_column_layout.' col-sm-6 rotateInDownLeft animated mg-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6>',
		'after_title'   => '</h6>',
	) );

}
add_action( 'widgets_init', 'ennova_widgets_init' );

//Editor Styling 
add_editor_style( array( 'css/editor-style.css') );

if ( ! function_exists( 'wp_body_open' ) ) {

	/**
	 * Shim for wp_body_open, ensuring backward compatibility with versions of WordPress older than 5.2.
	 */
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
}

if (!function_exists('ennova_archive_page_title')) :
        
        function ennova_archive_page_title($title)
        {
            if (is_category()) {
                $title = single_cat_title('', false);
            } elseif (is_tag()) {
                $title = single_tag_title('', false);
            } elseif (is_author()) {
                $title =  get_the_author();
            } elseif (is_post_type_archive()) {
                $title = post_type_archive_title('', false);
            } elseif (is_tax()) {
                $title = single_term_title('', false);
            }
            
            return $title;
        }
    
    endif;
add_filter('get_the_archive_title', 'ennova_archive_page_title');


if (!function_exists('ennova_edit_link')) :

    function ennova_edit_link($view = 'default')
    {
        global $post;
        if (is_single()) {
            edit_post_link(
                sprintf(
                    wp_kses(
                    /* translators: %s: Name of current post. Only visible to screen readers */
                        __('Edit <span class="screen-reader-text">%s</span>', 'ennova'),
                        array(
                            'span' => array(
                                'class' => array(),
                            ),
                        )
                    ),
                    get_the_title()
                ),
                '<span class="edit-link">',
                '</span>'
            );
        }

    } 
endif;